==> huaweicloudsdksis-3.0.73-py2.py3-none-any.whl: huaweicloudsdksis/v1/model/run_multi_modal_assessment_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RunMultiModalAssessmentRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'body': 'PostMultiModalAssessmentReq'
    }

    attribute_map = {
        'body': 'body'
    }

    def __init__(self, body=None):
        """RunMultiModalAssessmentRequest - a model defined in huaweicloud sdk"""
        
        

        self._body = None
        self.discriminator = None

        if body is not None:
            self.body = body

    @property
    def body(self):
        """Gets the body of this RunMultiModalAssessmentRequest.


        :return: The body of this RunMultiModalAssessmentRequest.
        :rtype: PostMultiModalAssessmentReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this RunMultiModalAssessmentRequest.


        :param body: The body of this RunMultiModalAssessmentRequest.
        :type: PostMultiModalAssessmentReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunMultiModalAssessmentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksis-3.0.107-py2.py3-none-any.whl: huaweicloudsdksis/v1/model/run_multi_modal_assessment_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RunMultiModalAssessmentRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'body': 'PostMultiModalAssessmentReq'
    }

    attribute_map = {
        'body': 'body'
    }

    def __init__(self, body=None):
        """RunMultiModalAssessmentRequest

        The model defined in huaweicloud sdk

        :param body: Body of the RunMultiModalAssessmentRequest
        :type body: :class:`huaweicloudsdksis.v1.PostMultiModalAssessmentReq`
        """
        
        

        self._body = None
        self.discriminator = None

        if body is not None:
            self.body = body

    @property
    def body(self):
        """Gets the body of this RunMultiModalAssessmentRequest.


        :return: The body of this RunMultiModalAssessmentRequest.
        :rtype: :class:`huaweicloudsdksis.v1.PostMultiModalAssessmentReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this RunMultiModalAssessmentRequest.


        :param body: The body of this RunMultiModalAssessmentRequest.
        :type body: :class:`huaweicloudsdksis.v1.PostMultiModalAssessmentReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunMultiModalAssessmentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
